@@ -1,7 +1,7 @@
 from .cli import TDKDict
 import argparse
 
-__version__ = "0.0.1"
+__version__ = "0.2.1"
 
 # parse arguments
 ap = argparse.ArgumentParser()
@@ -16,14 +16,7 @@ ap.add_argument(
     "--plain",
     action="store_true",
     default=False,
-    help="returns plain text output",
-)
-ap.add_argument(
-    "-f",
-    "--fuzzy",
-    action="store_true",
-    default=False,
-    help="returns fuzzy search results",
+    help="returns plain text output.",
 )
 ap.add_argument("-v", "--version", action="version", version="%(prog)s v" + __version__)
 args = ap.parse_args()
@@ -32,7 +25,7 @@ args = ap.parse_args()
 def cli():
     word = " ".join(args.word)
     if word == "":
-        print("Please enter a word.")
+        print("Kelime giriniz...")
     else:
         if args.plain:
             TDKDict(word).plain()
